<?php defined('SYSPATH') or die('No direct script access.');

class Controller_Handler_Sign extends Controller {

        protected $model;
        
        public function before() {
            parent::before();
            $this->model = new Model_Account;
            if(!$this->request->is_ajax() || Auth::isLoggedIn())
                throw HTTP_Exception::factory (403, 'no access');
        }

        public function action_in()
        {
            
            list($response, $data) = $this->checkAuthData(Arr::map('trim', $_POST));
            if($response['success'])
            {
                Auth::login($data['ID']);
                Auth::setAccountType($data['Type']);   
            }
            $this->response->body(json_encode($response));
        }
        
        private function checkAuthData($data)
        {
            $post = Validation::factory($data);
            $post->rule('login', 'email')->rule('login', 'not_empty');
            $res = null;
            if(!$post->check())
            {
                $post = Validation::factory($data);
                $post->rule('login', 'alpha_dash')->rule('login', 'not_empty');
                if($post->check())
                    $res = $this->model->getAccountInfoByLogin($data['login'], sha1($data['password']))->offsetGet(0);
            }
            else
                $res = $this->model->getAccountInfoByMail($data['login'], sha1($data['password']))->offsetGet(0);
            $response['success'] = $res['ID'] != 0;
            return array($response, $res);
        }
        
        public function action_up()
        {
            $data = Arr::map('trim', $_POST);
            $response = $this->validateActivationData($data);
            if($response['success']) 
            {
                $id = $this->model->activateAccount($data['login'], sha1($data['password']), 
                                            $data['email'], $data['activation_code']);
                $res = $this->model->getAccountInfoByLogin($data['login'], sha1($data['password']))->offsetGet(0);
                Auth::login($id);
                Auth::setAccountType($res['Type']);
            }
            $this->response->body(json_encode($response));
        }        

        private function validateActivationData($data)
        {
            $response['success'] = false;
            $post = Validation::factory($data);
            $post->rule('activation_code', 'alpha_numeric')
                ->rule('login', 'alpha_dash')
                ->rule('login', 'not_empty')
                ->rule('password', 'min_length', array(':value', 4))
                ->rule('confirm_password', 'matches', array(':validation', 'confirm_password', 'password'))
                ->rule('email', 'not_empty')
                ->rule('email', 'email')
                // ->rule('email', 'email_domain')
                ->rule('confirm_email', 'matches', array(':validation', 'confirm_email', 'email')); 
            if($post->check())
            {
                if($this->model->isActivationCodeValid($data['activation_code']))
                {
                    if($count = $this->model->isAccountExists($data['login'], $data['email']))
                    {
                        if($count['login'] != 0)
                            $post->error ('login', 'already_exists');
                        if($count['email'] != 0)
                            $post->error ('email', 'already_exists'); 
                        $response['count'] = $count;
                        $response['success'] = false;
                    }
                    else
                    {
                        $response['success'] = true;
                    }
                }
                else {
                    $post->error('activation_code', 'invalid_code');
                    $response['success'] = false;
               }
            }
            if(!$response['success'])
                $response['errors'] = $post->errors ('signin');
            return $response;
        }
        
        public function action_remindpass()
        {
            
        }        

        
}